@@ -2,8 +2,8 @@
 ;; Copyright (C) 2025 Eric Dallo
 ;; Author: Eric Dallo <ercdll1337@gmail.com>
 ;; Maintainer: Eric Dallo <ercdll1337@gmail.com>
-;; Package-Version: 20260209.1756
-;; Package-Revision: 9a6f6fc43d31
+;; Package-Version: 20260211.1525
+;; Package-Revision: 9aaa78afb932
 ;; Package-Requires: ((emacs "28.1") (dash "2.18.0") (f "0.20.0") (markdown-mode "2.3") (compat "30.1"))
 ;; Keywords: tools
 ;; Homepage: https://github.com/editor-code-assistant/eca-emacs
@@ -150,7 +150,9 @@
   (eca-api-request-async
    session
    :method "initialize"
-   :params (list :processId (emacs-pid)
+   :params (list :processId (unless (-some-> (buffer-file-name)
+                                      (file-remote-p))
+                              (emacs-pid))
                  :clientInfo (list :name "emacs"
                                    :version (emacs-version))
                  :capabilities (list :codeAssistant (list :chat t
